@@ -20,6 +20,7 @@ class Binance(exchanges.Exchange):
     SPOT_ID = "T9698EB7"
     MARGIN_ID = None
     FUTURE_ID = "uquVg2pc"
+    IS_SPONSORING = True
 
     @classmethod
     def get_name(cls):
@@ -33,13 +34,13 @@ class Binance(exchanges.Exchange):
         params.update({'newClientOrderId': self._get_order_custom_id()})
         return params
 
-    async def is_valid_account(self) -> (bool, str):
-        details = await self._exchange.connector.client.sapi_get_apireferral_ifnewuser(
-            params=self._exchange._get_params({
-                "apiAgentCode": self._get_id()
-            })
-        )
+    async def _inner_is_valid_account(self) -> (bool, str):
         try:
+            details = await self._exchange.connector.client.sapi_get_apireferral_ifnewuser(
+                params=self._exchange._get_params({
+                    "apiAgentCode": self._get_id()
+                })
+            )
             if not details.get("rebateWorking", False):
                 return False, "This account has a referral code, which is incompatible"
             if not details.get("ifNewUser", False):
