@@ -13,12 +13,16 @@
 #
 #  You should have received a copy of the GNU Lesser General Public
 #  License along with this library.
+import ccxt
+
+import trading_backend.errors
 
 
 class Exchange:
     SPOT_ID = None
     MARGIN_ID = None
     FUTURE_ID = None
+    IS_SPONSORING = False
 
     def __init__(self, exchange):
         self._exchange = exchange
@@ -27,12 +31,25 @@ class Exchange:
     def get_name(cls):
         return 'default'
 
+    @classmethod
+    def is_sponsoring(cls) -> bool:
+        return cls.IS_SPONSORING
+
     def get_orders_parameters(self, params=None) -> dict:
         if params is None:
             params = {}
         return params
 
     async def is_valid_account(self) -> (bool, str):
+        try:
+            return await self._inner_is_valid_account()
+        except ccxt.InvalidNonce as err:
+            raise trading_backend.errors.TimeSyncError(err)
+        except ccxt.ExchangeError as err:
+            raise trading_backend.errors.ExchangeAuthError(err)
+
+    async def _inner_is_valid_account(self) -> (bool, str):
+        await self._exchange.connector.client.fetch_balance()
         return True, None
 
     def _get_id(self):
